==> igniteui-react-charts-16.15.1.tgz: package/esm2015/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ChaikinVolatilityIndicator = /*@__PURE__*/ (() => {
    class ChaikinVolatilityIndicator extends StrategyBasedIndicator {
        get_t4() {
            return new ChaikinVolatilityIndicatorStrategy();
        }
        get t4() {
            return this.get_t4();
        }
        get_uh() {
            return ChaikinVolatilityIndicator.$;
        }
        get uh() {
            return this.get_uh();
        }
        get up() {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.uq));
        }
        set up(a) {
            this.h(ChaikinVolatilityIndicator.uq, a);
        }
        ua() {
            return this.up;
        }
        uj(a) {
            this.up = a;
        }
    }
    ChaikinVolatilityIndicator.$t = /*@__PURE__*/ markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.uq = /*@__PURE__*/ StrategyBasedIndicator.um(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
})();

==> igniteui-react-charts-16.16.3.tgz: package/esm2015/lib/ChaikinVolatilityIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ChaikinVolatilityIndicatorStrategy } from "./ChaikinVolatilityIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ChaikinVolatilityIndicator = /*@__PURE__*/ (() => {
    class ChaikinVolatilityIndicator extends StrategyBasedIndicator {
        get_uh() {
            return new ChaikinVolatilityIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return ChaikinVolatilityIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        get u2() {
            return typeGetValue(this.c(ChaikinVolatilityIndicator.u3));
        }
        set u2(a) {
            this.h(ChaikinVolatilityIndicator.u3, a);
        }
        un() {
            return this.u2;
        }
        uw(a) {
            this.u2 = a;
        }
    }
    ChaikinVolatilityIndicator.$t = /*@__PURE__*/ markType(ChaikinVolatilityIndicator, 'ChaikinVolatilityIndicator', StrategyBasedIndicator.$);
    ChaikinVolatilityIndicator.u3 = /*@__PURE__*/ StrategyBasedIndicator.uz(10, ChaikinVolatilityIndicator.$);
    return ChaikinVolatilityIndicator;
})();
